@@ -9,7 +9,7 @@ use Unicode::Security::Confusables;
 use Unicode::Normalize qw(NFD);
 use Unicode::UCD qw(charinfo charscript);
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 $VERSION = eval $VERSION;
 
 our @EXPORT_OK = qw(
@@ -193,7 +193,7 @@ Unicode::Security - Unicode security mechanisms
     $truth = whole_script_confusable($script, $string);
     $truth = mixed_script_confusable($string);
     $truth = mixed_script($string);
-    $truth = mixed_number($digits);
+    $truth = mixed_number($string);
     $level = restriction_level($string);
 
 =head1 DESCRIPTION
@@ -311,7 +311,7 @@ L<http://search.cpan.org/dist/Unicode-Security/>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014 gray <gray at cpan.org>, all rights reserved.
+Copyright (C) 2014-2015 gray <gray at cpan.org>, all rights reserved.
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
